@@ -1,6 +1,7 @@
 package oviewer
 
 import (
+	"bytes"
 	"errors"
 	"fmt"
 	"log"
@@ -43,11 +44,11 @@ func (root *Root) draw() {
 
 	// Section header
 	n := root.drawSectionHeader(lN)
-	if m.startTopFlag && lN < m.SectionHeaderNum {
+	if m.dupSectionHeader && lN < m.SectionHeaderNum {
 		lN = n
 		m.topLN = n
 	} else {
-		m.startTopFlag = false
+		m.dupSectionHeader = false
 	}
 	// Body
 	lX, lN = root.drawBody(lX, lN)
@@ -82,19 +83,16 @@ func (root *Root) drawHeader() int {
 			break
 		}
 
-		root.scr.numbers[y] = LineNumber{
-			number: lN,
-			wrap:   wrapNum,
-		}
+		root.scr.numbers[y] = newLineNumber(lN, wrapNum)
 
 		if root.Doc.ColumnMode {
 			root.columnHighlight(line)
 		}
+
+		nextX, nextN := root.drawLine(y, lX, lN, line.lc)
 		if root.Doc.LineNumMode {
 			root.blankLineNumber(y)
 		}
-
-		nextX, nextN := root.drawLine(y, lX, lN, line.lc)
 		// header style
 		root.yStyle(y, root.StyleHeader)
 
@@ -102,7 +100,7 @@ func (root *Root) drawHeader() int {
 		if nextN != lN {
 			lN = nextN
 			line, _ = m.getLineC(lN, m.TabWidth)
-			root.styleContent(lN, line)
+			root.styleContent(line)
 		}
 
 		if lX > 0 {
@@ -126,7 +124,7 @@ func (root *Root) drawSectionHeader(lN int) int {
 
 	pn := lN
 	// prevSection searches for the section above the specified line.
-	if m.startTopFlag && pn <= 0 {
+	if m.dupSectionHeader && pn <= 0 {
 		pn = 1
 	}
 	sectionLN, err := m.prevSection(pn)
@@ -147,18 +145,15 @@ func (root *Root) drawSectionHeader(lN int) int {
 	if pn > sectionLN {
 		sn = sectionLN
 		line, valid := m.getLineC(sn, m.TabWidth)
+		wrapNum := m.numOfWrap(sx, sn)
 		for y := m.headerLen; sn < sectionLN+m.SectionHeaderNum; y++ {
-			if root.Doc.LineNumMode {
-				if valid {
-					root.drawLineNumber(sn, y)
-				} else {
-					root.blankLineNumber(y)
-				}
-			}
-			if valid {
-				root.styleContent(lN, line)
-			}
+			root.scr.numbers[y] = newLineNumber(lN, wrapNum)
 			sx, nextN = root.drawLine(y, sx, sn, line.lc)
+
+			root.drawLineNumber(sn, y, valid)
+			if valid {
+				root.styleContent(line)
+			}
 			root.sectionLineHighlight(y, line.str)
 			m.headerLen += 1
 			if nextN != sn {
@@ -168,6 +163,11 @@ func (root *Root) drawSectionHeader(lN int) int {
 				sn = nextN
 				line, valid = m.getLineC(sn, m.TabWidth)
 			}
+			if sx > 0 {
+				wrapNum++
+			} else {
+				wrapNum = 0
+			}
 		}
 	}
 	return pn + (m.SectionHeaderNum - 1)
@@ -181,24 +181,14 @@ func (root *Root) drawBody(lX int, lN int) (int, int) {
 	line, valid := m.getLineC(lN, m.TabWidth)
 	root.bodyStyle(line.lc, root.StyleBody)
 	if valid {
-		root.styleContent(lN, line)
+		root.styleContent(line)
 	}
 	for y := m.headerLen; y < root.scr.vHeight-statusLine; y++ {
-		root.scr.numbers[y] = LineNumber{
-			number: lN,
-			wrap:   wrapNum,
-		}
-
-		if root.Doc.LineNumMode {
-			if valid {
-				root.drawLineNumber(lN, y)
-			} else {
-				root.blankLineNumber(y)
-			}
-		}
+		root.scr.numbers[y] = newLineNumber(lN, wrapNum)
 
 		nextX, nextY := root.drawLine(y, lX, lN, line.lc)
 
+		root.drawLineNumber(lN, y, valid)
 		if valid {
 			root.coordinatesStyle(lN, y, line.str)
 		}
@@ -212,7 +202,7 @@ func (root *Root) drawBody(lX int, lN int) (int, int) {
 			line, valid = m.getLineC(lN, m.TabWidth)
 			root.bodyStyle(line.lc, root.StyleBody)
 			if valid {
-				root.styleContent(lN, line)
+				root.styleContent(line)
 			}
 		}
 
@@ -226,7 +216,7 @@ func (root *Root) drawBody(lX int, lN int) (int, int) {
 }
 
 // styleContent applies the style of the content.
-func (root *Root) styleContent(lN int, line LineC) {
+func (root *Root) styleContent(line LineC) {
 	if root.Doc.PlainMode {
 		root.plainStyle(line.lc)
 	}
@@ -234,7 +224,7 @@ func (root *Root) styleContent(lN int, line LineC) {
 		root.columnHighlight(line)
 	}
 	root.multiColorHighlight(line)
-	root.searchHighlight(lN, line)
+	root.searchHighlight(line)
 }
 
 // coordinatesStyle applies the style of the coordinates.
@@ -307,25 +297,25 @@ func (root *Root) drawNoWrapLine(y int, startX int, lN int, lc contents) (int, i
 
 // bodyStyle applies the style from the beginning to the end of one line of the body.
 // Apply style to contents.
-func (root *Root) bodyStyle(lc contents, s OVStyle) {
+func (*Root) bodyStyle(lc contents, s OVStyle) {
 	RangeStyle(lc, 0, len(lc), s)
 }
 
 // searchHighlight applies the style of the search highlight.
 // Apply style to contents.
-func (root *Root) searchHighlight(lN int, line LineC) {
+func (root *Root) searchHighlight(line LineC) {
 	if root.searcher == nil || root.searcher.String() == "" {
 		return
 	}
 
-	indexes := root.searchPosition(lN, line.str)
+	indexes := root.searchPosition(line.str)
 	for _, idx := range indexes {
 		RangeStyle(line.lc, line.pos.x(idx[0]), line.pos.x(idx[1]), root.StyleSearchHighlight)
 	}
 }
 
 // plainStyle defaults to the original style.
-func (root *Root) plainStyle(lc contents) {
+func (*Root) plainStyle(lc contents) {
 	for x := 0; x < len(lc); x++ {
 		lc[x].style = tcell.StyleDefault
 	}
@@ -345,16 +335,38 @@ func (root *Root) multiColorHighlight(line LineC) {
 
 // blankLineNumber should be blank for the line number.
 func (root *Root) blankLineNumber(y int) {
-	m := root.Doc
-	numC := StrToContents(strings.Repeat(" ", root.scr.startX-1), m.TabWidth)
+	if root.scr.startX <= 0 {
+		return
+	}
+	numC := StrToContents(strings.Repeat(" ", root.scr.startX-1), root.Doc.TabWidth)
 	root.setContentString(0, y, numC)
 }
 
 // drawLineNumber draws the line number.
-func (root *Root) drawLineNumber(lN int, y int) {
+func (root *Root) drawLineNumber(lN int, y int, valid bool) {
 	m := root.Doc
+	if !m.LineNumMode {
+		return
+	}
+	if !valid {
+		root.blankLineNumber(y)
+		return
+	}
+	if root.scr.startX <= 0 {
+		return
+	}
+
+	number := lN
+	if m.lineNumMap != nil {
+		n, ok := m.lineNumMap.LoadForward(number)
+		if ok {
+			number = n
+		}
+	}
+	number = number - m.firstLine()
+
 	// Line numbers start at 1 except for skip and header lines.
-	numC := StrToContents(fmt.Sprintf("%*d", root.scr.startX-1, lN-m.firstLine()+1), m.TabWidth)
+	numC := StrToContents(fmt.Sprintf("%*d", root.scr.startX-1, number), m.TabWidth)
 	for i := 0; i < len(numC); i++ {
 		numC[i].style = applyStyle(tcell.StyleDefault, root.StyleLineNumber)
 	}
@@ -546,9 +558,9 @@ func (root *Root) leftStatus() (contents, int) {
 
 // normalLeftStatus returns the status of the left side of the normal mode.
 func (root *Root) normalLeftStatus() (contents, int) {
-	number := ""
-	if root.DocumentLen() > 1 && root.screenMode == Docs {
-		number = fmt.Sprintf("[%d]", root.CurrentDoc)
+	var leftStatus bytes.Buffer
+	if root.showDocNum && root.Doc.documentType != DocHelp && root.Doc.documentType != DocLog {
+		leftStatus.WriteString(fmt.Sprintf("[%d]", root.CurrentDoc))
 	}
 
 	modeStatus := ""
@@ -561,23 +573,22 @@ func (root *Root) normalLeftStatus() (contents, int) {
 	if root.General.FollowAll {
 		modeStatus = "(Follow All)"
 	}
-
 	// Watch mode doubles as FollowSection mode.
 	if root.Doc.WatchMode {
 		modeStatus += "(Watch)"
 	} else if root.Doc.FollowSection {
 		modeStatus = "(Follow Section)"
 	}
+	leftStatus.WriteString(modeStatus)
 
-	caption := ""
 	if root.Doc.Caption != "" {
-		caption = root.Doc.Caption
+		leftStatus.WriteString(root.Doc.Caption)
 	} else if root.Config.Prompt.Normal.ShowFilename {
-		caption = root.Doc.FileName
+		leftStatus.WriteString(root.Doc.FileName)
 	}
-
-	leftStatus := fmt.Sprintf("%s%s%s:%s", number, modeStatus, caption, root.message)
-	leftContents := StrToContents(leftStatus, -1)
+	leftStatus.WriteString(":")
+	leftStatus.WriteString(root.message)
+	leftContents := StrToContents(leftStatus.String(), -1)
 
 	if root.Config.Prompt.Normal.InvertColor {
 		color := tcell.ColorWhite
@@ -594,34 +605,40 @@ func (root *Root) normalLeftStatus() (contents, int) {
 
 // inputLeftStatus returns the status of the left side of the input.
 func (root *Root) inputLeftStatus() (contents, int) {
-	input := root.input
-	p := root.inputOpts() + input.Event.Prompt()
-	leftStatus := p + input.value
+	leftStatus := root.inputPrompt()
 	leftContents := StrToContents(leftStatus, -1)
-	return leftContents, len(p) + input.cursorX
+	return leftContents, len(leftContents)
 }
 
-// inputOpts returns a string describing the current search mode.
-func (root *Root) inputOpts() string {
-	var opts string
-
-	// The current search mode.
+// inputPrompt returns a string describing the input field.
+func (root *Root) inputPrompt() string {
+	var prompt bytes.Buffer
 	mode := root.input.Event.Mode()
-	if mode == Search || mode == Backsearch {
-		if root.Config.RegexpSearch {
-			opts += "(R)"
-		}
-		if root.Config.Incsearch {
-			opts += "(I)"
-		}
-		if root.Config.SmartCaseSensitive {
-			opts += "(S)"
-		} else if root.Config.CaseSensitive {
-			opts += "(Aa)"
-		}
+	modePrompt := root.input.Event.Prompt()
+
+	if mode != Search && mode != Backsearch && mode != Filter {
+		prompt.WriteString(modePrompt)
+		prompt.WriteString(root.input.value)
+		return prompt.String()
 	}
 
-	return opts
+	if mode == Filter && root.Doc.nonMatch {
+		prompt.WriteString("Non-match")
+	}
+	if root.Config.RegexpSearch {
+		prompt.WriteString("(R)")
+	}
+	if mode != Filter && root.Config.Incsearch {
+		prompt.WriteString("(I)")
+	}
+	if root.Config.SmartCaseSensitive {
+		prompt.WriteString("(S)")
+	} else if root.Config.CaseSensitive {
+		prompt.WriteString("(Aa)")
+	}
+	prompt.WriteString(modePrompt)
+	prompt.WriteString(root.input.value)
+	return prompt.String()
 }
 
 // rightStatus returns the status of the right side.
