@@ -7,11 +7,8 @@ import (
 // setDelimiterMode sets the inputMode to Delimiter.
 func (root *Root) setDelimiterMode() {
 	input := root.input
-	input.value = ""
-	input.cursorX = 0
-
+	input.reset()
 	input.DelimiterCandidate.toLast(root.Doc.ColumnDelimiter)
-
 	input.Event = newDelimiterEvent(input.DelimiterCandidate)
 }
 
@@ -41,12 +38,12 @@ func newDelimiterEvent(clist *candidate) *eventDelimiter {
 }
 
 // Mode returns InputMode.
-func (e *eventDelimiter) Mode() InputMode {
+func (*eventDelimiter) Mode() InputMode {
 	return Delimiter
 }
 
 // Prompt returns the prompt string in the input field.
-func (e *eventDelimiter) Prompt() string {
+func (*eventDelimiter) Prompt() string {
 	return "Delimiter:"
 }
 
@@ -59,11 +56,11 @@ func (e *eventDelimiter) Confirm(str string) tcell.Event {
 }
 
 // Up returns strings when the up key is pressed during input.
-func (e *eventDelimiter) Up(str string) string {
+func (e *eventDelimiter) Up(_ string) string {
 	return e.clist.up()
 }
 
 // Down returns strings when the down key is pressed during input.
-func (e *eventDelimiter) Down(str string) string {
+func (e *eventDelimiter) Down(_ string) string {
 	return e.clist.down()
 }
