@@ -5,8 +5,7 @@ import "github.com/gdamore/tcell/v2"
 // setSectionStartMode sets the inputMode to SectionStart.
 func (root *Root) setSectionStartMode() {
 	input := root.input
-	input.value = ""
-	input.cursorX = 0
+	input.reset()
 	input.Event = newSectionStartEvent(input.SectionStartCandidate)
 }
 
@@ -34,12 +33,12 @@ func newSectionStartEvent(clist *candidate) *eventSectionStart {
 }
 
 // Mode returns InputMode.
-func (e *eventSectionStart) Mode() InputMode {
+func (*eventSectionStart) Mode() InputMode {
 	return SectionStart
 }
 
 // Prompt returns the prompt string in the input field.
-func (e *eventSectionStart) Prompt() string {
+func (*eventSectionStart) Prompt() string {
 	return "Section start:"
 }
 
@@ -52,11 +51,11 @@ func (e *eventSectionStart) Confirm(str string) tcell.Event {
 }
 
 // Up returns strings when the up key is pressed during input.
-func (e *eventSectionStart) Up(str string) string {
+func (e *eventSectionStart) Up(_ string) string {
 	return e.clist.up()
 }
 
 // Down returns strings when the down key is pressed during input.
-func (e *eventSectionStart) Down(str string) string {
+func (e *eventSectionStart) Down(_ string) string {
 	return e.clist.down()
 }
