@@ -59,6 +59,7 @@ const (
 	actionAlternate      = "alter_rows_mode"
 	actionLineNumMode    = "line_number_mode"
 	actionSearch         = "search"
+	actionFilter         = "filter"
 	actionWrap           = "wrap_mode"
 	actionColumnMode     = "column_mode"
 	actionColumnWidth    = "column_width"
@@ -74,6 +75,7 @@ const (
 	actionNextDoc        = "next_doc"
 	actionPreviousDoc    = "previous_doc"
 	actionCloseDoc       = "close_doc"
+	actionCloseAllFilter = "close_all_filter"
 	actionToggleMouse    = "toggle_mouse"
 	actionMultiColor     = "multi_color"
 	actionJumpTarget     = "jump_target"
@@ -83,6 +85,7 @@ const (
 	inputSmartCaseSensitive = "input_smart_casesensitive"
 	inputIncSearch          = "input_incsearch"
 	inputRegexpSearch       = "input_regexp_search"
+	inputNonMatch           = "input_non_match"
 	inputPrevious           = "input_previous"
 	inputNext               = "input_next"
 	inputCopy               = "input_copy"
@@ -143,6 +146,7 @@ func (root *Root) handlers() map[string]func() {
 		actionRemoveAllMark:  root.removeAllMark,
 		actionSearch:         root.setSearchMode,
 		actionBackSearch:     root.setBackSearchMode,
+		actionFilter:         root.setSearchFilterMode,
 		actionDelimiter:      root.setDelimiterMode,
 		actionHeader:         root.setHeaderMode,
 		actionSkipLines:      root.setSkipLinesMode,
@@ -154,6 +158,7 @@ func (root *Root) handlers() map[string]func() {
 		actionNextDoc:        root.nextDoc,
 		actionPreviousDoc:    root.previousDoc,
 		actionCloseDoc:       root.closeDocument,
+		actionCloseAllFilter: root.closeAllFilter,
 		actionToggleMouse:    root.toggleMouse,
 		actionMultiColor:     root.setMultiColorMode,
 		actionJumpTarget:     root.setJumpTargetMode,
@@ -163,6 +168,7 @@ func (root *Root) handlers() map[string]func() {
 		inputSmartCaseSensitive: root.inputSmartCaseSensitive,
 		inputIncSearch:          root.inputIncSearch,
 		inputRegexpSearch:       root.inputRegexpSearch,
+		inputNonMatch:           root.inputNonMatch,
 		inputPrevious:           root.inputPrevious,
 		inputNext:               root.inputNext,
 		inputCopy:               root.CopySelect,
@@ -226,6 +232,7 @@ func defaultKeyBinds() KeyBind {
 		actionRemoveMark:     {"M"},
 		actionSearch:         {"/"},
 		actionBackSearch:     {"?"},
+		actionFilter:         {"&"},
 		actionDelimiter:      {"d"},
 		actionHeader:         {"H"},
 		actionSkipLines:      {"ctrl+s"},
@@ -237,6 +244,7 @@ func defaultKeyBinds() KeyBind {
 		actionNextDoc:        {"]"},
 		actionPreviousDoc:    {"["},
 		actionCloseDoc:       {"ctrl+k"},
+		actionCloseAllFilter: {"K"},
 		actionToggleMouse:    {"ctrl+alt+r"},
 		actionSuspend:        {"ctrl+z"},
 		actionMultiColor:     {"."},
@@ -247,6 +255,7 @@ func defaultKeyBinds() KeyBind {
 		inputSmartCaseSensitive: {"alt+s"},
 		inputIncSearch:          {"alt+i"},
 		inputRegexpSearch:       {"alt+r"},
+		inputNonMatch:           {"!"},
 		inputPrevious:           {"Up"},
 		inputNext:               {"Down"},
 		inputCopy:               {"ctrl+c"},
@@ -294,6 +303,7 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionNextDoc, "next document")
 	k.writeKeyBind(&b, actionPreviousDoc, "previous document")
 	k.writeKeyBind(&b, actionCloseDoc, "close current document")
+	k.writeKeyBind(&b, actionCloseAllFilter, "close all filtered documents")
 
 	writeHeader(&b, "Mark position")
 	k.writeKeyBind(&b, actionMark, "mark current position")
@@ -307,6 +317,7 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionBackSearch, "backward search mode")
 	k.writeKeyBind(&b, actionNextSearch, "repeat forward search")
 	k.writeKeyBind(&b, actionNextBackSearch, "repeat backward search")
+	k.writeKeyBind(&b, actionFilter, "filter search mode")
 
 	writeHeader(&b, "Change display")
 	k.writeKeyBind(&b, actionWrap, "wrap/nowrap toggle")
@@ -346,6 +357,7 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, inputSmartCaseSensitive, "smart case-sensitive toggle")
 	k.writeKeyBind(&b, inputRegexpSearch, "regular expression search toggle")
 	k.writeKeyBind(&b, inputIncSearch, "incremental search toggle")
+	k.writeKeyBind(&b, inputNonMatch, "non-match toggle")
 	k.writeKeyBind(&b, inputPrevious, "previous candidate")
 	k.writeKeyBind(&b, inputNext, "next candidate")
 	k.writeKeyBind(&b, inputCopy, "copy to clipboard.")
@@ -412,7 +424,7 @@ func setHandler(c *cbind.Configuration, name string, keys []string, handler func
 		if key == tcell.KeyRune {
 			c.SetRune(mod, ch, wrapEventHandler(handler))
 			// Added "shift+N" instead of 'N' to get it on windows.
-			if 'A' <= ch && ch <= 'Z' {
+			if 0x21 <= ch && ch <= 0x60 {
 				c.SetRune(mod|tcell.ModShift, ch, wrapEventHandler(handler))
 			}
 		} else {
