@@ -28,7 +28,7 @@ type Root struct {
 	// help
 	helpDoc *Document
 	// log
-	logDoc *Document
+	logDoc *LogDocument
 
 	// input contains the input mode.
 	input *Input
@@ -54,9 +54,8 @@ type Root struct {
 	// DocList is the list of documents.
 	DocList []*Document
 	scr     SCR
+	// Config is the configuration of ov.
 	Config
-	// screenMode represents the mode of screen.
-	screenMode ScreenMode
 	// Original position at the start of search.
 	OriginPos int
 
@@ -81,6 +80,8 @@ type Root struct {
 	mouseSelect bool
 	// mouseRectangle is a flag for rectangle selection.
 	mouseRectangle bool
+	// Show document number
+	showDocNum bool
 }
 
 // SCR contains the screen information.
@@ -104,9 +105,15 @@ type LineNumber struct {
 	wrap   int
 }
 
+func newLineNumber(number, wrap int) LineNumber {
+	return LineNumber{number: number, wrap: wrap}
+}
+
 // general structure contains the general of the display.
 // general contains values that determine the behavior of each document.
 type general struct {
+	// Caption is an additional caption to display after the file name.
+	Caption string
 	// ColumnDelimiterReg is a compiled regular expression of ColumnDelimiter.
 	ColumnDelimiterReg *regexp.Regexp
 	// ColumnDelimiter is a column delimiter.
@@ -318,18 +325,6 @@ var (
 	STDERRPIPE *os.File
 )
 
-// ScreenMode represents the state of the screen.
-type ScreenMode int
-
-const (
-	// Docs is a normal document screen mode.
-	Docs ScreenMode = iota
-	// Help is Help screen mode.
-	Help
-	// LogDoc is Error screen mode.
-	LogDoc
-)
-
 // MouseFlags represents which events of the mouse should be captured.
 // Set the mode to MouseDragEvents when the mouse is enabled in oviewer.
 // Does not track mouse movements except when dragging.
@@ -402,7 +397,6 @@ func NewOviewer(docs ...*Document) (*Root, error) {
 	root.DocList = append(root.DocList, docs...)
 	root.Doc = root.DocList[0]
 	root.input = NewInput()
-	root.screenMode = Docs
 
 	screen, err := tcellNewScreen()
 	if err != nil {
@@ -419,6 +413,10 @@ func NewOviewer(docs ...*Document) (*Root, error) {
 	}
 	root.logDoc = logDoc
 
+	if root.DocumentLen() > 1 {
+		root.showDocNum = true
+	}
+
 	return root, nil
 }
 
@@ -617,6 +615,10 @@ func (root *Root) Run() error {
 	}
 
 	root.optimizedMan()
+	if root.General.Caption != "" {
+		root.Doc.Caption = root.General.Caption
+	}
+
 	root.setModeConfig()
 	for n, doc := range root.DocList {
 		doc.general = root.Config.General
@@ -738,7 +740,7 @@ func (root *Root) debugMessage(msg string) {
 	if !root.Debug {
 		return
 	}
-	if root.Doc == root.logDoc {
+	if root.Doc == root.logDoc.Document {
 		return
 	}
 
@@ -891,6 +893,12 @@ func mergeGeneral(src general, dst general) general {
 	if len(dst.MultiColorWords) > 0 {
 		src.MultiColorWords = dst.MultiColorWords
 	}
+	if dst.SectionHeaderNum != 0 {
+		src.SectionHeaderNum = dst.SectionHeaderNum
+	}
+	if dst.Caption != "" {
+		src.Caption = dst.Caption
+	}
 	return src
 }
 
